@@ -21,7 +21,10 @@ class Volume(BaseAPI):
 
         self.plan = Plan(data['plan'])
         self.facility = Facility(data['facility'])
-        self.attached_to = data['attachments'][0]['device']['id']
+        try:
+            self.attached_to = data['attachments'][0]['device']['id']
+        except IndexError:
+            self.attached_to = None
 
         super(Volume, self).__init__(auth_token, consumer_token)
 
